##  Introduction
Searching and filtering in the SAP LeanIX inventory is a powerful way to efficiently manage and navigate a large number of fact sheets. You can quickly find a specific fact sheet or apply filters to narrow down fact sheets to the necessary subset. Additionally, you can search for specific filters or filter groups to easily apply the right filter criteria. You have the flexibility to manage these filters, choosing which ones to display or hide on the filter panel based on their relevance. Furthermore, you can save the search results for quick access in the future.
